require 'spec_helper'

describe Oztogo do 
  describe 'attributes' do
    let(:oztogo) { Oztogo::Base.new(:get, 'http://nothing') }

    before { allow(ENV).to receive(:[]).and_return('my-api-key') }

    it 'knows the endpoint', :vcr do
      expect(oztogo.api_endpoint).to eq 'https://api.navitia.io/v1/'
    end

    it 'receives the api key from environment variable', :vcr do
      expect(oztogo.api_key).to eq 'my-api-key'
    end
  end

  describe 'requirements' do
    let(:oztogo) { Oztogo::Base.new(:get, 'http://nothing') }

    it 'does not allow empty api key' do
      allow(ENV).to receive(:[]).and_return(nil)
      expect { oztogo.say.hello }.to raise_error(Oztogo::OztogoError)
    end
  end

  describe 'connection options' do
    let(:oztogo) { Oztogo::Base.new(:get, 'http://nothing') }

    before { allow(ENV).to receive(:[]).and_return('my-api-key') }

    it 'uses the Oztogo user agent', :vcr do
      expect(oztogo.instance_eval{ connection_options[:user_agent] }).to eq 'Oztogo'
    end

    it 'uses the api key for basic auth', :vcr do
      expect(oztogo.instance_eval{ connection_options[:basic_auth] }).to eq ({ username: 'my-api-key' })
    end
  end
end