require 'spec_helper'

describe Oztogo::SearchJourney do

  before { allow(ENV).to receive(:[]).and_return('95dd16c9-8b0a-406a-aba6-3ab663234cf4') }

  let(:journey_search) { Oztogo::SearchJourney.new({region: 'fr-idf', from: 'stop_point:TRN:SP:DUA8711371', to: 'stop_point:TRN:SP:DUA8711602'}) }

  describe 'prepare_query_string' do
    context 'without params' do
      it 'sets datetime to current datetime', :vcr do
        params = Hash.new
        expect(journey_search.prepare_query_string(params)[:datetime]).to eq DateTime.now.strftime('%Y%m%dT%H%M')
      end

      it 'sets min_nb_journeys', :vcr do
        params = Hash.new
        expect(journey_search.prepare_query_string(params)[:min_nb_journeys]).to eq 3
      end
    end

    context 'with params' do
      it 'kept the datatime params', :vcr do
        dt = DateTime.new(1988,11,9,0,0,0,'+1').strftime('%Y%m%dT%H%M')
        params = { datetime: dt }
        expect(journey_search.prepare_query_string(params)[:datetime]).to eq dt
      end

      it 'kept the min_nb_journeys params', :vcr do
        params = { min_nb_journeys: 7 }
        expect(journey_search.prepare_query_string(params)[:min_nb_journeys]).to eq 7
      end
    end
  end

  describe 'build_params_string', :vcr do
    it 'builds the params string' do
      params = { from: 'Paris', to: 'Berlin', foo: 'bar' }
      expect(journey_search.build_params_string(params)).to eq 'from=Paris&to=Berlin&foo=bar'
    end
  end
 
  it 'returns a list of journeys', :vcr do
    expect(journey_search.journeys.first).to be_a_kind_of(Oztogo::Journey)
  end
 
end
